##  FACT_SHEET_TAG_ADDED

```
{
  "id": 42840,
  "type": "FactSheetTagAddedEvent",
  "tagId": "5ab3558a-580b-422d-8a95-12f7f075dfd7",
  "fsType": "Application",
  "userId": "3et65c21-98f2-5376-acaa-fchf654b9c22",
  "tagName": "Public Cloud",
  "createdAt": "2024-02-16T13:14:08.732070Z",
  "fsIdAndRev": {
    "id": "95fbeddd-abdf-4552-a82b-ce37c287735c",
    "rev": 1
  },
  "workspaceId": "ae6756f1-4aag-4356-92c6-a390a60cb8fg",
  "tagGroupName": "Cloud Transformation",
  "transactionSequenceNumber": 75087
}
```



